==> ant-design-vue-4.1.1.jar: META-INF/resources/webjars/ant-design-vue/4.1.1/es/vc-checkbox/Checkbox.d.ts <==
export declare const checkboxProps: {
    prefixCls: StringConstructor;
    name: StringConstructor;
    id: StringConstructor;
    type: StringConstructor;
    defaultChecked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    checked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    disabled: BooleanConstructor;
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
    };
    readonly: BooleanConstructor;
    autofocus: BooleanConstructor;
    value: import("vue-types").VueTypeValidableDef<any>;
    required: BooleanConstructor;
};
declare const _default: import("vue").DefineComponent<{
    prefixCls: StringConstructor;
    name: StringConstructor;
    id: StringConstructor;
    type: StringConstructor;
    defaultChecked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    checked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    disabled: BooleanConstructor;
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
    };
    readonly: BooleanConstructor;
    autofocus: BooleanConstructor;
    value: import("vue-types").VueTypeValidableDef<any>;
    required: BooleanConstructor;
}, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("change" | "click")[], "change" | "click", import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    name: StringConstructor;
    id: StringConstructor;
    type: StringConstructor;
    defaultChecked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    checked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    disabled: BooleanConstructor;
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
    };
    readonly: BooleanConstructor;
    autofocus: BooleanConstructor;
    value: import("vue-types").VueTypeValidableDef<any>;
    required: BooleanConstructor;
}>> & {
    onClick?: (...args: any[]) => any;
    onChange?: (...args: any[]) => any;
}, {
    required: boolean;
    disabled: boolean;
    autofocus: boolean;
    defaultChecked: number | boolean;
    checked: number | boolean;
    readonly: boolean;
}, {}>;
export default _default;

==> ant-design-vue-4.2.6.jar: META-INF/resources/webjars/ant-design-vue/4.2.6/es/vc-checkbox/Checkbox.d.ts <==
export declare const checkboxProps: {
    prefixCls: StringConstructor;
    name: StringConstructor;
    id: StringConstructor;
    type: StringConstructor;
    defaultChecked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    checked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    disabled: BooleanConstructor;
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
    };
    readonly: BooleanConstructor;
    autofocus: BooleanConstructor;
    value: import("vue-types").VueTypeValidableDef<any>;
    required: BooleanConstructor;
};
declare const _default: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    name: StringConstructor;
    id: StringConstructor;
    type: StringConstructor;
    defaultChecked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    checked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    disabled: BooleanConstructor;
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
    };
    readonly: BooleanConstructor;
    autofocus: BooleanConstructor;
    value: import("vue-types").VueTypeValidableDef<any>;
    required: BooleanConstructor;
}>, () => import("vue/jsx-runtime").JSX.Element, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("change" | "click")[], "change" | "click", import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    name: StringConstructor;
    id: StringConstructor;
    type: StringConstructor;
    defaultChecked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    checked: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: any;
    };
    disabled: BooleanConstructor;
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
    };
    readonly: BooleanConstructor;
    autofocus: BooleanConstructor;
    value: import("vue-types").VueTypeValidableDef<any>;
    required: BooleanConstructor;
}>> & Readonly<{
    onClick?: (...args: any[]) => any;
    onChange?: (...args: any[]) => any;
}>, {
    required: boolean;
    disabled: boolean;
    autofocus: boolean;
    defaultChecked: number | boolean;
    checked: number | boolean;
    readonly: boolean;
}, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
